.. _install-ubuntu:

Install for Ubuntu
~~~~~~~~~~~~~~~~~~
This section describes how to install the Networking-ansible ML2 Driver
for Ubuntu 14.04 (LTS).

Install components
------------------

#. Install the packages:

   .. code-block:: console

      # apt-get update

      # apt-get install python2-networking-ansible
